<?php
// required files
require_once( get_theme_file_path('/inc/tgm.php') );
require_once( get_theme_file_path('/inc/metaboxes/post-metaboxes.php') );
require_once( get_theme_file_path('/inc/metaboxes/user-metabox.php') );
require_once( get_theme_file_path('/widgets/social-icons-widget.php') );

// hide acf from menu
add_filter('acf/settings/show_admin', '__return_false');

// content  with
if ( ! isset( $content_width ) ) $content_width = 960;

// theme funcitons
function balaka_theme_setup(){
	/*
    * Make theme available for translation.
    * Translations can be filed in the /languages/ directory.
    * If you're building a theme based on balaka, use a find and replace
    * to change 'balaka' to the name of your theme in all the template files.
    */
    load_theme_textdomain( 'balaka', get_template_directory() . '/languages' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'custom-header' );
	add_theme_support( 'custom-logo' );
	add_theme_support( 'automatic-feed-links' );
    add_theme_support( 'html5', array( 'comment-list', 'comment-form', 'search-form', 'gallery', 'caption' ) );
    add_theme_support( "post-formats", array("image", "gallery", "quote", "link", "audio", "video" ) );
    add_editor_style( "assets/css/editor-style.css" );
    // Set up the WordPress core custom background feature.
    add_theme_support( 'custom-background', apply_filters( 'balaka_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => '',
    ) ) );
    
    register_nav_menus(array(
        'top-menu' => __('Top Menu', 'balaka'),
        'footer-menu' => __('Footer Menu', 'balaka'),
    ));

    add_image_size('balaka_1024x500', 1024, 500, true);
    add_image_size('balaka_640x400', 640, 400, true);
    add_image_size('balaka_300x200', 300, 200, true);
}
add_action("after_setup_theme", "balaka_theme_setup");

function balaka_assets(){
	// balaka stylesheet
	wp_enqueue_style( "balaka-font", "//fonts.googleapis.com/css?family=Poppins:300,400,400i,500,500i,600,600i,700,700i,800,900" );
	wp_enqueue_style( "slickNav-css", get_template_directory_uri(). "/assets/css/slicknav.min.css", null, "1.0");
	wp_enqueue_style( "bootstrap-css", get_template_directory_uri(). "/assets/css/bootstrap.min.css", null, "1.0");
	wp_enqueue_style( "fontawesome-css", get_template_directory_uri(). "/assets/css/font-awesome.min.css", null, "1.0");
	wp_enqueue_style( "slick-css", get_template_directory_uri(). "/assets/css/slick.min.css", null, "1.0");
	wp_enqueue_style( "main-css", get_template_directory_uri(). "/assets/css/main.css", null, "1.0");
	wp_enqueue_style( "balaka-css", get_stylesheet_uri() );
	wp_enqueue_style( "responsive-css", get_template_directory_uri(). "/assets/css/responsive.css", null, "1.0");

	// balaka scripts
	wp_enqueue_script( "slicknav-js", get_template_directory_uri()."/assets/js/jquery.slicknav.min.js", array("jquery"), "1.0", true );
	wp_enqueue_script( "bootstrap-js", get_template_directory_uri()."/assets/js/bootstrap.min.js", array("jquery"), "v3.7", true );
	wp_enqueue_script( "slick-js", get_template_directory_uri()."/assets/js/slick.min.js", array("jquery"), "1.9.0", true );
	wp_enqueue_script( "active-js", get_template_directory_uri()."/assets/js/active.js", array("jquery"), "1.0", true );
	
    if ( is_singular() && comments_open() ) {
        wp_enqueue_script( "comment-reply" );
    }
}
add_action("wp_enqueue_scripts", "balaka_assets");

function balaka_widgets_init(){
    register_sidebar(array(
        'name'          => __( 'Right Sidebar', 'balaka' ),
        'id'            => 'right-sidebar',    // ID should be LOWERCASE  ! ! !
        'description'   => __( 'Add Right Sidebar widgets here', 'balaka' ),
        'before_widget' => '<div id="%1$s" class="single-widgets-wrapp %2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>'
    ));
    register_sidebar(array(
        'name'          => __( 'Footer Widgets', 'balaka' ),
        'id'            => 'footer-sidebar',    // ID should be LOWERCASE  ! ! !
        'description'   => __( 'Add Footer Sidebar widgets here', 'balaka' ),
        'before_widget' => '<div id="%1$s" class="%2$s">',
        'after_widget'  => '</div>',
        'before_title'  => '<h3 class="widget-title">',
        'after_title'   => '</h3>'
    ));



}
add_action('widgets_init', 'balaka_widgets_init');

// search area highlight function
function balaka_highlight_search_results($text){
    if(is_search()){
        $pattern = '/('. join('|', explode(' ', get_search_query())).')/i';
        $text = preg_replace($pattern, '<span class="search-highlight">\0</span>', $text);
    }
    return $text;
}
add_filter('the_content', 'balaka_highlight_search_results');
add_filter('the_excerpt', 'balaka_highlight_search_results');
add_filter('the_title', 'balaka_highlight_search_results');


// Javascript file type fix

function balaka_remove_type_attr($tag, $handle) {
    return preg_replace( "/type=['\"]text\/(javascript|css)['\"]/", '', $tag );
}
add_filter('style_loader_tag', 'balaka_remove_type_attr', 10, 2);
add_filter('script_loader_tag', 'balaka_remove_type_attr', 10, 2);

//add_filter('wp_calculate_image_srcset', '__return_false');

// social share buttons function


function balaka_social_sharing_buttons($content) {
    global $post;
    if(is_singular() || is_home()){
    
        // Get current page URL 
        $balakaURL = urlencode(get_permalink());
 
        // Get current page title
        $balakaTitle = htmlspecialchars(urlencode(html_entity_decode(get_the_title(), ENT_COMPAT, 'UTF-8')), ENT_COMPAT, 'UTF-8');
        // $balakaTitle = str_replace( ' ', '%20', get_the_title());
        
        // Get Post Thumbnail for pinterest
        $balakaThumbnail = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
 
        // Construct sharing URL without using any script
        $twitterURL = 'https://twitter.com/intent/tweet?text='.$balakaTitle.'&amp;url='.$balakaURL.'&amp;via=balaka';
        $facebookURL = 'https://www.facebook.com/sharer/sharer.php?u='.$balakaURL;
        $googleURL = 'https://plus.google.com/share?url='.$balakaURL;
        $linkedInURL = 'https://www.linkedin.com/shareArticle?mini=true&url='.$balakaURL.'&amp;title='.$balakaTitle;
 
        // Based on popular demand added Pinterest too
        $pinterestURL = 'https://pinterest.com/pin/create/button/?url='.$balakaURL.'&amp;media='.$balakaThumbnail[0].'&amp;description='.$balakaTitle;
 
        // Add sharing button at the end of page/page content
        $content .= '<!-- Implement your own superfast social sharing buttons without any JavaScript loading. No plugin required. Detailed steps here: http://balaka.me/1VIxAsz -->';
        $content .= '<div class="post-share">';
        $content .= '<span class="share_title"><i class="fa fa-share" aria-hidden="true"></i>
Share Article :</span> <a class="balaka-link balaka-facebook" href="'.$facebookURL.'" target="_blank"><i class="fa fa-facebook"></i></a>';
        $content .= '<a class="balaka-link balaka-twitter" href="'. $twitterURL .'" target="_blank"><i class="fa fa-twitter"></i></a>';
        $content .= '<a class="balaka-link balaka-googleplus" href="'.$googleURL.'" target="_blank"><i class="fa fa-google-plus"></i></a>';
        $content .= '<a class="balaka-link balaka-linkedin" href="'.$linkedInURL.'" target="_blank"><i class="fa fa-linkedin"></i></a>';
        $content .= '<a class="balaka-link balaka-pinterest" href="'.$pinterestURL.'" data-pin-custom="true" target="_blank"><i class="fa fa-pinterest"></i></a>';
        $content .= '</div>';
        
        return $content;
    }else{
        // if not a post/page then don't include sharing button
        return $content;
    }
};
add_filter( 'the_content', 'balaka_social_sharing_buttons');


// wp_oembed_get modify

function oembed_modify( $return, $data, $url ){

    if( is_object( $data ) ){
        // Remove the unwanted attributes:
        $return = str_ireplace(
            array( 
                'frameborder="0"'
            ),
            '',
            $return
        );
    }
    return $return;
}
add_filter('oembed_dataparse', 'oembed_modify', 10,3 );

// comment callback function

function balaka_comment($comment, $args, $depth) {
    if ( 'div' === $args['style'] ) {
        $tag       = 'div';
        $add_below = 'comment';
    } else {
        $tag       = 'li';
        $add_below = 'div-comment';
    }?>
    <<?php echo $tag; ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?> id="comment-<?php comment_ID() ?>"><?php 
    if ( 'div' != $args['style'] ) { ?>
        <div id="div-comment-<?php comment_ID() ?>" class="comment-body"><?php
    } ?>
        <div class="comment-author vcard"><?php 
            if ( $args['avatar_size'] != 0 ) {
                echo get_avatar( $comment, $args['avatar_size'] ); 
            } 
            printf( __( '<cite class="fn">%s</cite> <span class="says">says:</span>', 'balaka' ), get_comment_author_link() ); ?>
        </div><?php 
        if ( $comment->comment_approved == '0' ) { ?>
            <em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'balaka' ); ?></em><br/><?php 
        } ?>
        <div class="comment-meta commentmetadata">
            <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>"><?php
                /* translators: 1: date, 2: time */
                printf( 
                    __('%1$s at %2$s', 'balaka'), 
                    get_comment_date(),  
                    get_comment_time() 
                ); ?>
            </a><?php 
            edit_comment_link( __( 'Edit', 'balaka' ), '  ', '' ); ?>
        </div>
        <?php comment_text(); ?>

        <div class="reply"><?php 
                comment_reply_link( 
                    array_merge( 
                        $args, 
                        array( 
                            'add_below' => $add_below, 
                            'depth'     => $depth, 
                            'max_depth' => $args['max_depth'] 
                        ) 
                    ) 
                ); ?>
        </div><?php 
    if ( 'div' != $args['style'] ) : ?>
        </div><?php 
    endif;
}

